lilypondfiletools.PaperBlock
============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.lilypond_format

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.is_formatted_when_empty

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.minimal_page_breaking

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__repr__

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`
